@@ -17,7 +17,7 @@ def init():
 
     typer.echo(typer.style("fetching data from", fg="green"))
 
-    command.init(alembic_cfg, ".", template="generic", package=True)
+    command.init(alembic_cfg, "alembic", template="generic", package=True)
     return
 
 
